@@ -171,7 +171,7 @@ func parseUnprintableStyle(styleOption string) (textstyles.UnprintableStyleT, er
 func parseScrollHint(scrollHint string) (textstyles.CellWithMetadata, error) {
 	scrollHint = strings.ReplaceAll(scrollHint, "ESC", "\x1b")
 	hintAsLine := reader.NewLine(scrollHint)
-	parsedTokens := hintAsLine.HighlightedTokens(twin.StyleDefault, twin.StyleDefault, nil, nil, nil).StyledRunes
+	parsedTokens := hintAsLine.HighlightedTokens(twin.StyleDefault, twin.StyleDefault, nil, nil).StyledRunes
 	if len(parsedTokens) == 1 {
 		return parsedTokens[0], nil
 	}
@@ -327,25 +327,23 @@ func russiaNotSupported() {
 	os.Exit(1)
 }
 
-// On man pages, disable line numbers by default.
+// For git output and man pages, disable line numbers by default.
 //
 // Before paging, "man" first checks the terminal width and formats the man page
-// to fit that width.
+// to fit that width. Git does that as well for git diff --stat.
 //
-// Then, if moor adds line numbers, the rightmost part of the man page won't be
-// visible.
+// Then, if moor adds line numbers, the rightmost part of the page will scroll
+// out of view.
 //
-// So we try to detect showing man pages, and in that case disable line numbers
-// so that the rightmost part of the page is visible by default.
+// So we try to this, and in that case disable line numbers so that the
+// rightmost part of the page is visible by default.
+//
+// See also internal/haveLoadedManPage(), where we try to detect man pages by
+// their contents.
 func noLineNumbersDefault() bool {
-	if os.Getenv("MANPATH") != "" {
-		// Set by "man" on macOS, skip line numbers in this case
-		return true
-	}
-
 	if os.Getenv("MAN_PN") != "" {
-		// Set by "man" on Ubuntu 22.04.4 when I tested it inside of Docker,
-		// skip line numbers in this case
+		// Set by "man" on Ubuntu 22.04.4 when I tested it inside of Docker.
+		log.Debug("MAN_PN is set, skipping line numbers for man page")
 		return true
 	}
 
@@ -354,6 +352,7 @@ func noLineNumbersDefault() bool {
 
 		// Neither logs nor diffs are helped by line numbers, turn them off by
 		// default.
+		log.Debug("GIT_EXEC_PATH is set, skipping line numbers when paging git output")
 		return true
 	}
 
@@ -402,6 +401,7 @@ func pagerFromArgs(
 		"lang", nil,
 		"File contents, used for highlighting. Mime type or file extension (\"html\"). Default is to guess by filename.", parseLexerOption)
 	terminalFg := flagSet.Bool("terminal-fg", false, "Use terminal foreground color rather than style foreground for plain text")
+	noSearchLineHighlight := flagSet.Bool("no-search-line-highlight", false, "Do not highlight the background of lines with search hits")
 
 	defaultFormatter, err := parseColorsOption("auto")
 	if err != nil {
@@ -557,10 +557,10 @@ func pagerFromArgs(
 
 	stdinName := ""
 	if os.Getenv("PAGER_LABEL") != "" {
-		stdinName = "[stdin] " + os.Getenv("PAGER_LABEL")
+		stdinName = os.Getenv("PAGER_LABEL")
 	} else if os.Getenv("MAN_PN") != "" {
 		// MAN_PN is set by GNU man. Example value: "printf(1)"
-		stdinName = "[stdin] " + os.Getenv("MAN_PN")
+		stdinName = os.Getenv("MAN_PN")
 	}
 
 	// Display the input file(s) contents
@@ -634,6 +634,7 @@ func pagerFromArgs(
 	pager.ScrollRightHint = *scrollRightHint
 	pager.SideScrollAmount = int(*shift)
 	pager.TabSize = int(*tabSize)
+	pager.WithSearchHitLineBackground = !*noSearchLineHighlight
 
 	pager.TargetLine = targetLine
 	if *follow && pager.TargetLine == nil {
